@@ -2,9 +2,12 @@ from typing import Dict, Hashable, List, Optional, Tuple
 
 import netCDF4 as nc
 import numpy as np
+import utm
 import xarray as xr
 from numpy.lib.recfunctions import rename_fields as np_rename_fields
 
+from lfmaptools.utilities import latlon_to_utm_epsg
+
 
 class lfnc(object):
     def __init__(self, filename):
@@ -21,6 +24,9 @@ class lfnc(object):
 
         self.vars = list(self.data[self.tiles[0]].variables)
 
+        self.centre_latitude = self.get_attr("centre_latitude")
+        self.centre_longitude = self.get_attr("centre_longitude")
+
     def __del__(self):
 
         self.data.close()
@@ -38,8 +44,13 @@ class lfnc(object):
         y_var = "y_distance" if "y_distance" in self.vars else "y"
 
         if vars is not None:
+            if type(vars) is not list:
+                vars = [vars]
             drop_variables = self.vars.copy()
+            print(drop_variables)
+            print(vars + [x_var, y_var])
             for v in vars + [x_var, y_var]:
+                print(v)
                 drop_variables.remove(v)
         else:
             drop_variables = []
@@ -74,6 +85,13 @@ class lfnc(object):
         if y_var == "y_distance":
             data = data.rename({"y_distance": "y"})
 
+        if self.centre_latitude is not None and self.centre_longitude is not None:
+            utm_full = utm.from_latlon(self.centre_latitude, self.centre_longitude)
+            utmCode = latlon_to_utm_epsg(self.centre_latitude, self.centre_longitude)
+            data["x"] = data["x"] + utm_full[0]
+            data["y"] = data["y"] + utm_full[1]
+            data.rio.write_crs(utmCode, inplace=True)
+
         return data
 
 
